@@ -49,31 +49,9 @@
 #if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
 #include "cgroupconn.h"
 #include "cgroupuse.h"
-#include "use_bwrap.h"
-#include <sys/prctl.h>
-#include <linux/capability.h>
 #endif
 
-void ls_stderr(const char * fmt, ...)
-{
-    char buf[1024];
-    char *p = buf;
-    struct timeval  tv;
-    struct tm       tm;
-    gettimeofday(&tv, NULL);
-    localtime_r(&tv.tv_sec, &tm);
-    p += snprintf(p, 1024, "%04d-%02d-%02d %02d:%02d:%02d.%06d ",
-        tm.tm_year + 1900, tm.tm_mon + 1, tm.tm_mday,
-        tm.tm_hour, tm.tm_min, tm.tm_sec, (int)tv.tv_usec);
-    fprintf(stderr, "%.*s", (int)(p - buf), buf);
-
-    va_list ap;
-    va_start(ap, fmt);
-    vsnprintf(buf, sizeof(buf), fmt, ap);
-    va_end(ap);
-    fprintf(stderr, "%s", buf);
-    //DEBUG_MESSAGE("stderr message: %s", buf);
-}
+#define uint32_t unsigned long
 
 static uid_t        s_uid;
 
@@ -102,7 +80,7 @@ static int (*fp_lve_leave)(struct liblve *, uint32_t *) = NULL;
 static int (*fp_lve_jail)(struct passwd *, char *) = NULL;
 static int load_lve_lib()
 {
-    s_liblve = dlopen("liblve.so.0", RTLD_NOW | RTLD_GLOBAL);
+    s_liblve = dlopen("liblve.so.0", RTLD_LAZY);
     if (s_liblve)
     {
         fp_lve_is_available = (lve_is_available)dlsym(s_liblve, "lve_is_available");
@@ -115,20 +93,14 @@ static int load_lve_lib()
                 {
                     setreuid(s_uid, uid);
                     if (!(*fp_lve_is_available)())
-                    {
                         s_enable_lve = 0;
-                        ls_stderr("LVE disabled, lve_is_available() failure.\n");
-                    }
                     setreuid(uid, s_uid);
                 }
             }
         }
     }
     else
-    {
         s_enable_lve = 0;
-        ls_stderr("LVE disabled, dlopen() failed: %s.\n", dlerror());
-    }
     return (s_liblve) ? 0 : -1;
 }
 
@@ -158,10 +130,9 @@ static int init_lve()
         s_lve = NULL;
         return LS_FAIL;
     }
-    //ls_stderr("lscgid (%d) LVE initialized !\n", s_pid );
+    //fprintf( stderr, "lscgid (%d) LVE initialized !\n", getpid() );
 
-    //ls_stderr("lscgid (%d) LVE initialized: %d, %p !\n", s_pid,
-    //        s_enable_lve, fp_lve_jail );
+    //fprintf( stderr, "lscgid (%d) LVE initialized: %d, %p !\n", getpid(), s_enable_lve, fp_lve_jail );
     return 0;
 
 }
@@ -186,13 +157,6 @@ static void log_cgi_error(const char *func, const char *arg,
 }
 
 
-#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-static void set_cgi_error(char *func, char *arg)
-{
-    log_cgi_error(func, arg, NULL);
-}
-#endif
-
 static int timed_read(int fd, char *pBuf, int len, int timeout)
 {
     struct pollfd   pfd;
@@ -331,62 +295,44 @@ static int setUIDs(uid_t uid, gid_t gid, char *pChroot)
 }
 
 
-int applyLimits(lscgid_t *cgid)
+static int applyLimits(lscgid_req *pCGI)
 {
-    lscgid_req *req = &cgid->m_data;
-    //ls_stderr("Proc: %ld, data: %ld\n", pCGI->m_nproc.rlim_cur,
+    //fprintf( stderr, "Proc: %ld, data: %ld\n", pCGI->m_nproc.rlim_cur,
     //                        pCGI->m_data.rlim_cur );
 #if defined(RLIMIT_AS) || defined(RLIMIT_DATA) || defined(RLIMIT_VMEM)
-    if (req->m_data.rlim_cur)
+    if (pCGI->m_data.rlim_cur)
     {
 #if defined(RLIMIT_AS)
-        setrlimit(RLIMIT_AS, &req->m_data);
+        setrlimit(RLIMIT_AS, &pCGI->m_data);
 #elif defined(RLIMIT_DATA)
-        setrlimit(RLIMIT_DATA, &req->m_data);
+        setrlimit(RLIMIT_DATA, &pCGI->m_data);
 #elif defined(RLIMIT_VMEM)
-        setrlimit(RLIMIT_VMEM, &req->m_data);
+        setrlimit(RLIMIT_VMEM, &pCGI->m_data);
 #endif
     }
 #endif
 
 #if defined(RLIMIT_NPROC)
-    if (req->m_nproc.rlim_cur)
-        setrlimit(RLIMIT_NPROC, &req->m_nproc);
+    if (pCGI->m_nproc.rlim_cur)
+        setrlimit(RLIMIT_NPROC, &pCGI->m_nproc);
 #endif
 
 #if defined(RLIMIT_CPU)
-    //if (req->m_cpu.rlim_cur)
-    //    setrlimit(RLIMIT_CPU, &req->m_cpu);
+    //if (pCGI->m_cpu.rlim_cur)
+    //    setrlimit(RLIMIT_CPU, &pCGI->m_cpu);
 #endif
 
-    if ((!s_uid) && (req->m_uid || req->m_gid))
-    {
-        if (setUIDs(req->m_uid, req->m_gid, cgid->m_pChroot) == -1)
-            return 403;
-    }
     return 0;
 }
 
 
-//called after uid/gid/chroot change
-static int changeStderrLog(lscgid_t *pCGI)
+static int changeStderrLog(const char *path)
 {
-    const char *path = pCGI->m_stderrPath;
-    if (pCGI->m_pChroot)
-    {
-        if (pCGI->m_data.m_chrootPathLen > 1
-            && strncmp(path, pCGI->m_pChroot, pCGI->m_data.m_chrootPathLen) == 0)
-        {
-            path += pCGI->m_data.m_chrootPathLen;
-            if (*path != '/')
-                --path;
-        }
-    }
     int newfd = open(path, O_WRONLY | O_CREAT | O_APPEND, 0644);
     if (newfd == -1)
     {
-        ls_stderr("lscgid (%d): failed to change stderr log to: %s\n",
-                  getpid(), path);
+        fprintf(stderr, "lscgid (%d): failed to change stderr log to: %s\n",
+                getpid(), path);
         return -1;
     }
     if (newfd != 2)
@@ -399,85 +345,6 @@ static int changeStderrLog(lscgid_t *pCGI)
 
 
 #if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-
-
-static const char *s_user_slice_dir = NULL;
-
-static int detect_cgroup_user_slice_dir()
-{
-    struct stat st;
-    if (stat("/sys/fs/cgroup/user.slice", &st) == 0)
-        s_user_slice_dir = "/sys/fs/cgroup/user.slice";
-    else if (stat("/sys/fs/cgroup/systemd/user.slice", &st) == 0)
-        s_user_slice_dir = "/sys/fs/cgroup/systemd/user.slice";
-    else
-    {
-        s_user_slice_dir = (const char *)-1LL;
-        return -1;
-    }
-    return 0;
-}
-
-
-bool is_cgroup_v2_available()
-{
-    if (s_user_slice_dir == NULL)
-        detect_cgroup_user_slice_dir();
-    if (s_user_slice_dir == (const char *)-1LL)
-        return false;
-    return true;
-}
-
-
-static int cgroup_v2(int uid, int pid)
-{
-    char user_slice[1024];
-
-    if (!is_cgroup_v2_available())
-        return -1;
-
-    snprintf(user_slice, sizeof(user_slice), "%s/user-%d.slice",
-             s_user_slice_dir, uid);
-    if (mkdir(user_slice, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH) == 0
-        || errno == EEXIST)
-    {
-        strcat(user_slice, "/litespeed-exec.scope");
-        if (mkdir(user_slice, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH)
-                    == 0 || errno == EEXIST)
-        {
-            strcat(user_slice, "/cgroup.procs");
-            FILE *fp = fopen(user_slice, "a");
-            //if there is no cgroup, we may hit permission denied. Wait moment.
-            if (fp == NULL)
-            {
-                struct timespec ns;
-                ns.tv_sec = 0;
-                ns.tv_nsec = 1 * 1000000; //10ms
-                int count = 200;
-                while (fp == NULL && count--)
-                {
-                    nanosleep(&ns, NULL);
-                    fp = fopen(user_slice, "a");
-                }
-            }
-            if (fp == NULL)
-            {
-                ls_stderr("Error opening %s for writing: %s", user_slice,
-                        strerror(errno));
-                return -1;
-            }
-            else
-            {
-                fprintf(fp, "%d\n", (int) pid);
-                fclose(fp);
-                return 0;
-            }
-        }
-    }
-    return -1;
-}
-
-
 static int cgroup_env(lscgid_t *pCGI)
 {
     if (getuid())
@@ -545,56 +412,21 @@ static int cgroup_process(lscgid_t *pCGI)
 #endif
 
 
-//called before uid/gid/chroot change.
-static int fixStderrLogPermission(lscgid_t *pCGI)
-{
-    struct stat st;
-    const char *path = pCGI->m_stderrPath;
-
-    if (lstat(path, &st) == -1)
-        return 0;
-    if (S_ISLNK(st.st_mode))
-        return -1;
-    if (st.st_uid != pCGI->m_data.m_uid && pCGI->m_data.m_uid > 0)
-    {
-        pCGI->m_stderrPath = NULL;
-        int newfd = open(path, O_WRONLY | O_APPEND, 0644);
-        if (newfd == -1)
-        {
-            ls_stderr("lscgid (%d): failed to open stderr: %s\n",
-                      getpid(), path);
-            return -1;
-        }
-        if (newfd != 2)
-        {
-            dup2(newfd, 2);
-            close(newfd);
-        }
-    }
-    return 0;
-}
-
-
 static int execute_cgi(lscgid_t *pCGI)
 {
     char ch;
-    uid_t uid;
-    uint32_t pid = (uint32_t)getpid();
+#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
+    cgroup_process(pCGI);
+#endif
+
 
     if (setpriority(PRIO_PROCESS, 0, pCGI->m_data.m_priority))
         perror("lscgid: setpriority()");
+    applyLimits(&pCGI->m_data);
 
     if (pCGI->m_stderrPath)
-        fixStderrLogPermission(pCGI);
+        changeStderrLog(pCGI->m_stderrPath);
 
-    uid = pCGI->m_data.m_uid;
-
-#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-    if (pCGI->m_cgroup && uid != 0)
-    {
-        cgroup_v2(uid, pid);
-    }
-#endif
 
 #ifdef HAS_CLOUD_LINUX
 
@@ -613,8 +445,8 @@ static int execute_cgi(lscgid_t *pCGI)
         }
         if (ret < 0)
         {
-            ls_stderr("lscgid (%d): enter LVE (%d) : result: %d !\n", pid,
-                      pCGI->m_data.m_uid, ret);
+            fprintf(stderr, "lscgid (%d): enter LVE (%d) : result: %d !\n", getpid(),
+                    pCGI->m_data.m_uid, ret);
             log_cgi_error("lscgid", NULL, "lve_enter() failure, reached resource limit");
             return 500;
         }
@@ -632,10 +464,10 @@ static int execute_cgi(lscgid_t *pCGI)
             ret = (*fp_lve_jail)(pw, error_msg);
             if (ret < 0)
             {
-                ls_stderr("lscgid (%d): LVE jail(%d) result: %d, error: %s !\n",
-                          pid, pCGI->m_data.m_uid, ret, error_msg);
-                //set_cgi_error( "lscgid: CloudLinux jail() failure.", NULL );
-                return 508;
+                fprintf(stderr, "lscgid (%d): LVE jail(%d) ressult: %d, error: %s !\n",
+                        getpid(), pCGI->m_data.m_uid, ret, error_msg);
+                log_cgi_error("lscgid", NULL, "jail() failure");
+                return 500;
             }
         }
     }
@@ -643,18 +475,12 @@ static int execute_cgi(lscgid_t *pCGI)
 
 #endif
 
-#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-    if (pCGI->m_data.m_flags & LSCGID_FLAG_DROP_CAPS)
+    if ((!s_uid) && (pCGI->m_data.m_uid || pCGI->m_data.m_gid))
     {
-        if (0 != prctl(PR_CAPBSET_DROP, CAP_SETUID, 0, 0, 0))
-            ls_stderr("dropping capabilities failed: %s", strerror(errno));
+        if (setUIDs(pCGI->m_data.m_uid, pCGI->m_data.m_gid,
+                    pCGI->m_pChroot) == -1)
+            return 403;
     }
-#endif
-
-    if (pCGI->m_stderrPath)
-        changeStderrLog(pCGI);
-
-
     ch = *(pCGI->m_argv[0]);
     * pCGI->m_argv[0] = 0;
     const char *dir = pCGI->m_cwdPath;
@@ -689,19 +515,7 @@ static int execute_cgi(lscgid_t *pCGI)
     }
 
     umask(pCGI->m_data.m_umask);
-#if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
-    {
-        int rc = 0, done = 0;
-        rc = exec_using_bwrap(pCGI, set_cgi_error, &done);
-        if (rc || done)
-            return rc;
-    }
-#endif
-
-    if (applyLimits(pCGI) == 403)
-        return 403;
-
-    //ls_stderr( "execute_cgi m_umask=%03o\n", pCGI->m_data.m_umask );
+    //fprintf( stderr, "execute_cgi m_umask=%03o\n", pCGI->m_data.m_umask );
     if (execve(pCGI->m_pCGIDir, pCGI->m_argv, pCGI->m_env) == -1)
     {
         log_cgi_error("lscgid: execve()", pCGI->m_pCGIDir, NULL);
@@ -729,16 +543,16 @@ static int process_req_data(lscgid_t *cgi_req)
     p += cgi_req->m_data.m_exePathLen;
     if (p > pEnd)
     {
-        ls_stderr("exePathLen=%d\n", cgi_req->m_data.m_exePathLen);
+        fprintf(stderr, "exePathLen=%d\n", cgi_req->m_data.m_exePathLen);
         return 500;
     }
     cgi_req->m_argv[0] = p;
     p += cgi_req->m_data.m_exeNameLen + 1;
 
-//    ls_stderr("exePath=%s\n", cgi_req->m_pCGIDir );
-//    ls_stderr("nargv=%d\n", cgi_req->m_data.m_nargv );
-//    ls_stderr("exeName=%s\n", cgi_req->m_argv[0] );
-//    ls_stderr("exePath ends with %s\n",
+//    fprintf( stderr, "exePath=%s\n", cgi_req->m_pCGIDir );
+//    fprintf( stderr, "nargv=%d\n", cgi_req->m_data.m_nargv );
+//    fprintf( stderr, "exeName=%s\n", cgi_req->m_argv[0] );
+//    fprintf( stderr, "exePath ends with %s\n",
 //            cgi_req->m_pCGIDir + cgi_req->m_data.m_exePathLen );
 
     for (i = 1; i < cgi_req->m_data.m_nargv - 1; ++i)
@@ -754,11 +568,11 @@ static int process_req_data(lscgid_t *cgi_req)
         p += len;
         if (p > pEnd)
             return 500;
-//        ls_stderr("arg %d, len=%d, str=%s\n", i, len, cgi_req->m_argv[i] );
+//        fprintf( stderr, "arg %d, len=%d, str=%s\n", i, len, cgi_req->m_argv[i] );
     }
     if (*p != 0 || *(p + 1) != 0)
     {
-        ls_stderr("argv is not terminated with \\0\\0\n");
+        fprintf(stderr, "argv is not terminated with \\0\\0\n");
         return 500;
     }
     p += sizeof(short);
@@ -766,7 +580,7 @@ static int process_req_data(lscgid_t *cgi_req)
         return 500;
     cgi_req->m_argv[i] = NULL;
 
-//    ls_stderr("nenv=%d\n", cgi_req->m_data.m_nenv );
+//    fprintf( stderr, "nenv=%d\n", cgi_req->m_data.m_nenv );
     for (i = 0; i < cgi_req->m_data.m_nenv - 1; ++i)
     {
 #if defined( sparc )
@@ -777,8 +591,6 @@ static int process_req_data(lscgid_t *cgi_req)
         p += sizeof(short);
 #endif
         cgi_req->m_env[i] = p;
-        //ls_stderr("env %d, len=%d, str=%s\n", i, len, cgi_req->m_env[i]);
-
         if (*p == 'L')
         {
             if (strncasecmp(p, "LS_STDERR_LOG=", 14) == 0)
@@ -793,32 +605,21 @@ static int process_req_data(lscgid_t *cgi_req)
                 --cgi_req->m_data.m_nenv;
                 cgi_req->m_cwdPath = p + 7;
             }
-            else if (strncasecmp(p, "LS_BWRAP=", 9) == 0)
-            {
-                --i;
-                --cgi_req->m_data.m_nenv;
-                cgi_req->m_bwrap = strtol(p + 9, NULL, 10);
-            }
-            else if (strncasecmp(p, "LS_CGROUP=", 10) == 0)
-            {
-                --i;
-                --cgi_req->m_data.m_nenv;
-                cgi_req->m_cgroup = strtol(p + 10, NULL, 10);
-            }
         }
         p += len;
         if (p > pEnd)
             return 500;
+//        fprintf( stderr, "env %d, len=%d, str=%s\n", i, len, cgi_req->m_env[i] );
     }
     if (*p != 0 || *(p + 1) != 0)
     {
-        ls_stderr("env is not terminated with \\0\\0\n");
+        fprintf(stderr, "env is not terminated with \\0\\0\n");
         return 500;
     }
     p += sizeof(short);
     if (p != pEnd)
     {
-        ls_stderr("header is too big\n");
+        fprintf(stderr, "header is too big\n");
         return 500;
     }
     cgi_req->m_env[i] = NULL;
@@ -886,7 +687,7 @@ static int recv_req(int fd, lscgid_t *cgi_req, int timeout)
     ret = process_req_header(cgi_req);
     if (ret)
         return ret;
-    //ls_stderr("1 Proc: %ld, data: %ld\n", cgi_req->m_data.m_nproc.rlim_cur,
+    //fprintf( stderr, "1 Proc: %ld, data: %ld\n", cgi_req->m_data.m_nproc.rlim_cur,
     //                        cgi_req->m_data.m_data.rlim_cur );
 
     if (cgi_req->m_data.m_type == LSCGID_TYPE_SUEXEC)
@@ -915,8 +716,8 @@ static int recv_req(int fd, lscgid_t *cgi_req, int timeout)
         if ((FDPass::readFd(fd, &nothing, 1, &cgi_req->m_fdReceived) == -1) ||
             (cgi_req->m_fdReceived == -1))
         {
-            ls_stderr("lscgid: read_fd() failed: %s\n",
-                    strerror(errno));
+            fprintf(stderr, "lscgid: read_fd() fd %d failed: %s\n",
+                    fd, strerror(errno));
             return 500;
         }
         if (cgi_req->m_fdReceived != STDIN_FILENO)
@@ -926,7 +727,7 @@ static int recv_req(int fd, lscgid_t *cgi_req, int timeout)
             cgi_req->m_fdReceived = -1;
         }
     }
-    //ls_stderr("2 Proc: %ld, data: %ld\n", cgi_req->m_data.m_nproc.rlim_cur,
+    //fprintf( stderr, "2 Proc: %ld, data: %ld\n", cgi_req->m_data.m_nproc.rlim_cur,
     //                        cgi_req->m_data.m_data.rlim_cur );
     return 0;
 
@@ -1031,7 +832,7 @@ static void sigterm(int sig)
 static void sigusr1(int sig)
 {
     pid_t pid = getppid();
-    if (pid != -1 && pid != 1)
+    if (pid != -1)
         kill(pid, SIGHUP);
 }
 
@@ -1062,18 +863,19 @@ static void processSigchild()
             int sig_num = WTERMSIG(status[1]);
             if (sig_num != 15)
             {
-                ls_stderr("Cgid: Child process with pid: %d was killed by signal: %d, core dump: %d\n",
-                          status[0], sig_num,
+                fprintf(stderr,
+                        "Cgid: Child process with pid: %d was killed by signal: %d, core dump: %d\n",
+                        status[0], sig_num,
 #ifdef WCOREDUMP
-                          WCOREDUMP(status[1])
+                        WCOREDUMP(status[1])
 #else
-                          - 1
+                        - 1
 #endif
 
                        );
             }
         }
-        //ls_stderr( "reape child %d: status: %d\n", pid, status );
+        //fprintf( stderr, "reape child %d: status: %d\n", pid, status );
     }
 
 }
@@ -1128,6 +930,7 @@ int lscgid_main(int fd, char *argv0, const char *secret, char *pSock)
 #ifdef HAS_CLOUD_LINUX
 
 #if defined(linux) || defined(__linux) || defined(__linux__) || defined(__gnu_linux__)
+
     if ((sEnv = getenv("LVE_ENABLE")) != NULL)
     {
         s_enable_lve = atol(sEnv);
