@@ -90,6 +90,7 @@ public:
 
     char   *begin() const           {   return pbuf;  }
     char   *end() const             {   return pend;  }
+    char *buf_end()                 {   return pbufend;   }
 
     void    used(int size)          {   pend += size;  }
     void    clear()                 {   pend = pbuf;  }
@@ -114,12 +115,13 @@ public:
     int     xGrow(int size, ls_xpool_t *pool)
     {   return ls_buf_xgrow(this, size, pool);  }
 
-    bool    empty() const           {   return (pbuf == pend);  }
-    bool    full() const            {   return (pend == pbufend);  }
+    bool    empty() const           {   return (pbuf == pend);      }
+    bool    full() const            {   return (pend == pbufend);   }
 
-    int     getOffset(const char *p) const        {   return p - pbuf;  }
-    char   *getp(int offset) const                  {   return pbuf + offset;  }
-    void    swap(AutoBuf &rhs)      {   ls_buf_swap(this, &rhs);  }
+    int     getOffset(const char *p) const  {   return p - pbuf;        }
+    char   *getp(int offset) const          {   return pbuf + offset;   }
+    char   *get_ptr(int offset) const       {   return pbuf + offset;   }
+    void    swap(AutoBuf &rhs)              {   ls_buf_swap(this, &rhs);}
 
     int     pop_front_to(char *pBuf, int size)
     {   return ls_buf_popfrontto(this, pBuf, size);  }
@@ -134,13 +136,6 @@ public:
     int     append(const char *pBuf)
     {   return ls_buf_append(this, pBuf);  }
 
-    void append(char ch)
-    {
-        if (available() < 1)
-            grow(1);
-        *pend++ = ch;
-    }
-
     void    append_unsafe(char ch)  {   *pend++ = ch;  }
 
     int append_unsafe(const char *pBuf, int size)
@@ -149,7 +144,7 @@ public:
         used(size);
         return size;
     }
-    
+
     int reserve_append(int size)
     {
         if (size == 0)
@@ -162,7 +157,7 @@ public:
         used(size);
         return size;
     }
-    
+
 
     int appendAllocOnly(int size)
     {
@@ -185,8 +180,8 @@ public:
 
     static void xDestroy(AutoBuf *p, ls_xpool_t *pool)
     {   ls_buf_xd(p, pool);  }
-    
-    
+
+
     int make_room_deepcopy(int pos, int size)
     {
         if (size == 0)
@@ -202,7 +197,7 @@ public:
         used(size);
         return size;
     }
-    
+
 };
 
 class XAutoBuf : private ls_xbuf_t
